pub enum SkillTreeNodeKind {
Dispatch,
Aggregate,
LeafHolder,
}Expand description
To make this selection, categorize each type of node in our skill tree scaffold.
Variants
Dispatch
This variant is used for enumerations branching into distinct paths.
Aggregate
This variant is used for grouping child nodes into a combined structure.
LeafHolder
This variant is used for the final leaf-holder nodes (without children).