StrippedNodeData

Struct StrippedNodeData 

pub struct StrippedNodeData { /* private fields */ }

Implementations

Source

impl StrippedNodeData

pub fn name(&self) -> &String

The node’s official UpperCamelCase identifier

pub fn kind(&self) -> &SkillTreeNodeKind

pub fn n_leaves(&self) -> &Option<usize>

If this node is a LeafHolder, then n_leaves is an integer denoting how many leaves it contains.

n_leaves is a measure of the models representational power at this level of the tree.

n_leaves indicates how many states within the domain we can access at this level.

pub fn capstone(&self) -> &Option<bool>

If this node is a capstone node in the original data structure, we set capstone to true.

It may be left out (ie, set to None) if this node is not a capstone or if this field is not specified in the model.

pub fn children(&self) -> &Option<Vec<NamedChildSpec>>

children is an array referencing the structural child nodes of this node. Each child object has:

  • name (the child’s official UpperCamelCase identifier)
  • optional (a boolean indicating whether in our domain model, this path through the tree is optional)
  • probability (float in [0..1] – represents a likelihood that this path is chosen in our domain)
Source

impl StrippedNodeData

pub fn set_name(&mut self, val: String) -> &mut Self

The node’s official UpperCamelCase identifier

pub fn set_kind(&mut self, val: SkillTreeNodeKind) -> &mut Self

pub fn set_n_leaves(&mut self, val: Option<usize>) -> &mut Self

If this node is a LeafHolder, then n_leaves is an integer denoting how many leaves it contains.

n_leaves is a measure of the models representational power at this level of the tree.

n_leaves indicates how many states within the domain we can access at this level.

pub fn set_capstone(&mut self, val: Option<bool>) -> &mut Self

If this node is a capstone node in the original data structure, we set capstone to true.

It may be left out (ie, set to None) if this node is not a capstone or if this field is not specified in the model.

pub fn set_children(&mut self, val: Option<Vec<NamedChildSpec>>) -> &mut Self

children is an array referencing the structural child nodes of this node. Each child object has:

  • name (the child’s official UpperCamelCase identifier)
  • optional (a boolean indicating whether in our domain model, this path through the tree is optional)
  • probability (float in [0..1] – represents a likelihood that this path is chosen in our domain)