pub struct StrippedNodeDataBuilder { /* private fields */ }Expand description
Builder for StrippedNodeData.
Implementations
Sourceimpl StrippedNodeDataBuilder
impl StrippedNodeDataBuilder
Sourcepub fn name(&mut self, value: String) -> &mut Self
pub fn name(&mut self, value: String) -> &mut Self
The node’s official UpperCamelCase identifier
pub fn kind(&mut self, value: SkillTreeNodeKind) -> &mut Self
Sourcepub fn n_leaves(&mut self, value: Option<usize>) -> &mut Self
pub fn n_leaves(&mut self, value: Option<usize>) -> &mut Self
If this node is a LeafHolder, then n_leaves is an integer denoting how many leaves it contains.
n_leaves is a measure of the models representational power at this level of the tree.
n_leaves indicates how many states within the domain we can access at this level.
Sourcepub fn capstone(&mut self, value: Option<bool>) -> &mut Self
pub fn capstone(&mut self, value: Option<bool>) -> &mut Self
If this node is a capstone node in the original data structure, we set capstone to true.
It may be left out (ie, set to None) if this node is not a capstone or if this field is not specified in the model.
Sourcepub fn children(&mut self, value: Option<Vec<NamedChildSpec>>) -> &mut Self
pub fn children(&mut self, value: Option<Vec<NamedChildSpec>>) -> &mut Self
children is an array referencing the structural child nodes of this node.
Each child object has:
- name (the child’s official UpperCamelCase identifier)
- optional (a boolean indicating whether in our domain model, this path through the tree is optional)
- probability (float in
[0..1]– represents a likelihood that this path is chosen in our domain)
Sourcepub fn build(&self) -> Result<StrippedNodeData, StrippedNodeDataBuilderError>
pub fn build(&self) -> Result<StrippedNodeData, StrippedNodeDataBuilderError>