Structs
- Named
Child Spec - To generate this structure, describe a single child entry beneath a
DispatchorAggregatenode. This description includes: - Named
Child Spec Builder - Builder for
NamedChildSpec. - Stripped
Node Data - Stripped
Node Data Builder - Builder for
StrippedNodeData. - Stripped
String Skeleton - We want to create a stripped version of our
StringSkeleton, called a StrippedStringSkeleton. - Stripped
String Skeleton Builder - Builder for
StrippedStringSkeleton.
Enums
- Named
Child Spec Builder Error - Error type for NamedChildSpecBuilder
- Skill
Tree Node Kind - To make this selection, categorize each type of node in our skill tree scaffold.
- Stripped
Node Data Builder Error - Error type for StrippedNodeDataBuilder
- Stripped
String Skeleton Builder Error - Error type for StrippedStringSkeletonBuilder
Functions
- promote_
missing_ child_ nodes_ with_ defaults - This helper function scans a
StringSkeletonfor any child references (inAggregateorDispatch) whose child names do not appear as keys in theStringSkeleton.map. For each such missing child, we “promote” it into a syntheticLeafHolderentry, with default parameters (e.g.n_leaves=9,capstone=false). This prevents aggregator or dispatch children from disappearing when we later convert to aStrippedStringSkeleton.