pub struct StrippedNodeData { /* private fields */ }Implementations
Sourceimpl StrippedNodeData
impl StrippedNodeData
pub fn kind(&self) -> &SkillTreeNodeKind
Sourcepub fn n_leaves(&self) -> &Option<usize>
pub fn n_leaves(&self) -> &Option<usize>
If this node is a LeafHolder, then n_leaves is an integer denoting how many leaves it contains.
n_leaves is a measure of the models representational power at this level of the tree.
n_leaves indicates how many states within the domain we can access at this level.
Sourcepub fn capstone(&self) -> &Option<bool>
pub fn capstone(&self) -> &Option<bool>
If this node is a capstone node in the original data structure, we set capstone to true.
It may be left out (ie, set to None) if this node is not a capstone or if this field is not specified in the model.
Sourcepub fn children(&self) -> &Option<Vec<NamedChildSpec>>
pub fn children(&self) -> &Option<Vec<NamedChildSpec>>
children is an array referencing the structural child nodes of this node.
Each child object has:
- name (the child’s official UpperCamelCase identifier)
- optional (a boolean indicating whether in our domain model, this path through the tree is optional)
- probability (float in
[0..1]– represents a likelihood that this path is chosen in our domain)
Sourceimpl StrippedNodeData
impl StrippedNodeData
Sourcepub fn set_name(&mut self, val: String) -> &mut Self
pub fn set_name(&mut self, val: String) -> &mut Self
The node’s official UpperCamelCase identifier
pub fn set_kind(&mut self, val: SkillTreeNodeKind) -> &mut Self
Sourcepub fn set_n_leaves(&mut self, val: Option<usize>) -> &mut Self
pub fn set_n_leaves(&mut self, val: Option<usize>) -> &mut Self
If this node is a LeafHolder, then n_leaves is an integer denoting how many leaves it contains.
n_leaves is a measure of the models representational power at this level of the tree.
n_leaves indicates how many states within the domain we can access at this level.
Sourcepub fn set_capstone(&mut self, val: Option<bool>) -> &mut Self
pub fn set_capstone(&mut self, val: Option<bool>) -> &mut Self
If this node is a capstone node in the original data structure, we set capstone to true.
It may be left out (ie, set to None) if this node is not a capstone or if this field is not specified in the model.
Sourcepub fn set_children(&mut self, val: Option<Vec<NamedChildSpec>>) -> &mut Self
pub fn set_children(&mut self, val: Option<Vec<NamedChildSpec>>) -> &mut Self
children is an array referencing the structural child nodes of this node.
Each child object has:
- name (the child’s official UpperCamelCase identifier)
- optional (a boolean indicating whether in our domain model, this path through the tree is optional)
- probability (float in
[0..1]– represents a likelihood that this path is chosen in our domain)